JHData
================

Various interfaces for interacting with files stored in the cloud

## Installing

Install the [PyPI Package](https://pypi.org/project/jhdata/):

    pip install jhdata

## Examples

TODO
